<?php

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Util\SupUtilities;

class FilialAtendidaNaoAtendidaPeloFornecedorService {
    
    
    public function __construct($entityManager, SupUtilities $supUtilities, $environment)
    {
        $this->connection = $entityManager->getConnection();
        $this->supUtilities = $supUtilities;
        $this->environment = $environment;
    }
    
    public function insertReforfil($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $sql = "INSERT INTO REFORFIL(CDFORNECED, 
                                         CDFILIAL, 
                                         CDPERIENTR,
                                         IDUTCALENDCMPGERACAOAF,
                                         NRORG)
                                  SELECT FO.CDFORNECED, 
                                         FI.CDFILIAL, 
                                         :CDPERIENTR,
                                         :IDUTCALENDCMPGERACAOAF,
                                         FO.NRORG
                                    FROM FORNECEDOR FO
                                    JOIN LISTA L1 ON FO.CDFORNECED = L1.CDLISTA AND FO.NRORG = L1.NRORG,
                                         FILIAL FI
                                    JOIN LISTA L2 ON FI.CDFILIAL   = L2.CDLISTA AND FI.NRORG = L2.NRORG
                                   WHERE L1.NRLISTA    = :P_CDFORNECED
                                     AND L2.NRLISTA    = :P_CDFILIAL
                                     AND L2.NRORG      = :P_NRORG
                                     AND NOT EXISTS (SELECT 1
                                                       FROM REFORFIL
                                                      WHERE REFORFIL.CDFORNECED = FO.CDFORNECED
                                                        AND REFORFIL.CDFILIAL   = FI.CDFILIAL)";
        } else {
            $sql = "INSERT INTO REFORFIL(CDFORNECED, 
                                         CDFILIAL, 
                                         CDPERIENTR,
                                         IDUTCALENDCMPGERACAOAF,
                                         NRORG)
                                  SELECT FO.CDFORNECED, 
                                         FI.CDFILIAL,
                                         :CDPERIENTR,
                                         :IDUTCALENDCMPGERACAOAF,
                                         FI.NRORG
                                    FROM (SELECT CDFILIAL, NRORG
                                            FROM FILIAL
                                           WHERE CDFILIAL = :P_CDFILIAL
                                             AND NRORG    = :P_NRORG) FI,
                                         (SELECT CDFORNECED
                                            FROM FORNECEDOR
                                           WHERE CDFORNECED = :P_CDFORNECED
                                             AND NRORG      = :P_NRORG) FO
                                   WHERE NOT EXISTS (SELECT 1
                                                       FROM REFORFIL
                                                      WHERE REFORFIL.CDFORNECED = FO.CDFORNECED
                                                        AND REFORFIL.CDFILIAL = FI.CDFILIAL 
                                                        AND REFORFIL.NRORG = FI.NRORG)";
        }                                                        
                            
        try {
            $param = [
                'P_CDFILIAL'             => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_CDFORNECED'           => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'CDPERIENTR'             => isset($row['CDPERIENTR']) ? $row['CDPERIENTR'] : null,
                'IDUTCALENDCMPGERACAOAF' => isset($row['IDUTCALENDCMPGERACAOAF']) ? $row['IDUTCALENDCMPGERACAOAF'] : null,
                'P_NRORG'                => $this->environment->getNrOrg()
            ];
            return $this->supUtilities->crud($sql, $param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateReforfil($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $sql = "UPDATE REFORFIL
                       SET CDPERIENTR = :CDPERIENTR,
                           IDUTCALENDCMPGERACAOAF = :IDUTCALENDCMPGERACAOAF
                     WHERE EXISTS (SELECT 1
                                     FROM LISTA
                                    WHERE LISTA.NRLISTA = :P_CDFORNECED
                                      AND LISTA.NRORG   = :P_NRORG
                                      AND LISTA.CDLISTA = CDFORNECED) 
                       AND EXISTS (SELECT 1
                                     FROM LISTA L
                                    WHERE L.NRLISTA = :P_CDFILIAL
                                      AND L.NRORG   = :P_NRORG
                                      AND L.CDLISTA = CDFILIAL)";
        } else {
            $sql = "UPDATE REFORFIL
                       SET CDPERIENTR = :CDPERIENTR,
                           IDUTCALENDCMPGERACAOAF = :IDUTCALENDCMPGERACAOAF
                     WHERE CDFORNECED = :P_CDFORNECED 
                       AND CDFILIAL   = :P_CDFILIAL
                       AND NRORG      = :P_NRORG";   
        }
        
        try {
            $param = [
                'P_CDFILIAL'             => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_CDFORNECED'           => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'CDPERIENTR'             => isset($row['CDPERIENTR']) ? $row['CDPERIENTR'] : null,
                'IDUTCALENDCMPGERACAOAF' => isset($row['IDUTCALENDCMPGERACAOAF']) ? $row['IDUTCALENDCMPGERACAOAF'] : null,
                'P_NRORG'                => $this->environment->getNrOrg()
            ];
            return $this->supUtilities->crud($sql, $param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function deleteReforfil($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $sql = "DELETE FROM REFORFIL
                          WHERE EXISTS (SELECT 1
                                          FROM LISTA
                                         WHERE LISTA.NRLISTA = :P_CDFORNECED 
                                           AND LISTA.NRORG   = :P_NRORG
                                           AND LISTA.CDLISTA = CDFORNECED) 
                            AND EXISTS (SELECT 1
                                          FROM LISTA L
                                         WHERE L.NRLISTA = :P_CDFILIAL
                                           AND L.NRORG   = :P_NRORG
                                           AND L.CDLISTA = CDFILIAL)";
        } else {
            $sql = "DELETE FROM REFORFIL
                          WHERE CDFORNECED = :P_CDFORNECED 
                            AND CDFILIAL   = :P_CDFILIAL
                            AND NRORG      = :P_NRORG";
        }
        
        try {
            $param = [
                'P_CDFILIAL'             => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_CDFORNECED'           => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'P_NRORG'                => $this->environment->getNrOrg()
            ];
            return $this->supUtilities->crud($sql, $param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function gravaPrazoExpedFil($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        try {
            if(empty($row['CDPERIENTR'])){
                $this->deletePrazoExpedFil($row);
            } else {
                if(isset($row['QTDIASPRAZOEXPED'])){
                    if(isset($nrlistaForn) && isset($nrlistaForn)){
                        $this->updatePrazoExpedFil($row, $nrlistaForn, $nrlistaFili);
                        $this->insertPrazoExpedFil($row, $nrlistaForn, $nrlistaFili);
                    } else {
                        $this->updatePrazoExpedFil($row);
                        $this->insertPrazoExpedFil($row);
                    }
                }
            }
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    private function insertPrazoExpedFil($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $ins = "INSERT INTO PRAZOFORNEXPEDFIL (NRPRAZOFORNEXPEDFIL, 
                                                   CDFORNECED, 
                                                   CDFILIAL, 
                                                   QTDIASPRAZOEXPED)
                                            SELECT SEQ_PRAZOFORNEXPEDFIL.NEXTVAL,
                                                   FORNECEDOR.CDFORNECED,
                                                   FILIAL.CDFILIAL,
                                                   :P_QTDIASPRAZOEXPED
                                              FROM LISTA FO, LISTA FI, FORNECEDOR, FILIAL
                                             WHERE FO.CDLISTA = FORNECEDOR.CDFORNECED
                                               AND FI.CDLISTA = FILIAL.CDFILIAL
                                               AND FO.NRLISTA = :P_CDFORNECED
                                               AND FI.NRLISTA = :P_CDFILIAL
                                               AND NOT EXISTS (SELECT 1
                                                                 FROM PRAZOFORNEXPEDFIL PZ
                                                                WHERE PZ.CDFORNECED = FORNECEDOR.CDFORNECED
                                                                  AND PZ.CDFILIAL   = FILIAL.CDFILIAL)";
        } else {
            $ins = "INSERT INTO PRAZOFORNEXPEDFIL (NRPRAZOFORNEXPEDFIL, 
                                                   CDFORNECED, 
                                                   CDFILIAL, 
                                                   QTDIASPRAZOEXPED)
                                            SELECT SEQ_PRAZOFORNEXPEDFIL.NEXTVAL,
                                                   FORNECEDOR.CDFORNECED,
                                                   FILIAL.CDFILIAL,
                                                   :P_QTDIASPRAZOEXPED
                                              FROM FORNECEDOR, FILIAL
                                             WHERE FORNECEDOR.CDFORNECED = :P_CDFORNECED
                                               AND FILIAL.CDFILIAL       = :P_CDFILIAL
                                               AND NOT EXISTS (SELECT 1
                                                                 FROM PRAZOFORNEXPEDFIL PZ
                                                                WHERE PZ.CDFORNECED = FORNECEDOR.CDFORNECED
                                                                  AND PZ.CDFILIAL   = FILIAL.CDFILIAL)";
        }
        try {
            $param = [
                'P_CDFORNECED'       => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'P_CDFILIAL'         => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_QTDIASPRAZOEXPED' => $row['QTDIASPRAZOEXPED']
            ];
            return $this->supUtilities->crud($ins, $param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    private function updatePrazoExpedFil($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $upt = "UPDATE PRAZOFORNEXPEDFIL
                       SET QTDIASPRAZOEXPED = :P_QTDIASPRAZOEXPED
                     WHERE EXISTS (SELECT 1
                                     FROM PRAZOFORNEXPEDFIL PZ
                                     JOIN LISTA FO ON PZ.CDFORNECED = FO.CDLISTA
                                     JOIN LISTA FI ON PZ.CDFILIAL   = FI.CDLISTA
                                    WHERE PZ.NRPRAZOFORNEXPEDFIL = PRAZOFORNEXPEDFIL.NRPRAZOFORNEXPEDFIL
                                      AND FO.NRLISTA = :P_CDFORNECED
                                      AND FI.NRLISTA = :P_CDFILIAL)";
            
        } else {
            $upt = "UPDATE PRAZOFORNEXPEDFIL
                       SET QTDIASPRAZOEXPED = :P_QTDIASPRAZOEXPED
                     WHERE CDFORNECED = :P_CDFORNECED
                       AND CDFILIAL   = :P_CDFILIAL";
        }
        
        try {
            $param = [
                'P_CDFORNECED'       => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'P_CDFILIAL'         => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_QTDIASPRAZOEXPED' => $row['QTDIASPRAZOEXPED']
            ];
            return $this->supUtilities->crud($upt, $param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function deletePrazoExpedFil($row) 
    {
        try {
            if(isset($row['NRPRAZOFORNEXPEDFIL'])){
                $query = "DELETE FROM PRAZOFORNEXPEDFIL 
                           WHERE NRPRAZOFORNEXPEDFIL = :NRPRAZOFORNEXPEDFIL";
                $params = [
                    'NRPRAZOFORNEXPEDFIL' => $row['NRPRAZOFORNEXPEDFIL'],
                ];
            } else {
                $query = "DELETE FROM PRAZOFORNEXPEDFIL
                              WHERE CDFORNECED = :P_CDFORNECED
                                AND CDFILIAL   = :P_CDFILIAL";
                                
                $params = [
                    'P_CDFORNECED' => $row['CDFORNECED'],
                    'P_CDFILIAL'   => $row['CDFILIAL'],
                ];
            }
            
            $this->supUtilities->crud($query, $params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function verifyFornecedor($row)
    {
        $query = "SELECT CDFORNECED
                    FROM FILIAL
                    JOIN REFOREG ON FILIAL.CDREGIAO = REFOREG.CDREGIAO 
                                AND FILIAL.NRORG    = REFOREG.NRORG
                   WHERE REFOREG.CDFORNECED = :P_CDFORNECED
                     AND FILIAL.CDFILIAL    = :P_CDFILIAL
                     AND REFOREG.NRORG      = :P_NRORG";
                        
        try {
            $params = [
                'P_CDFORNECED' => $row['CDFORNECED'],
                'P_CDFILIAL'   => $row['CDFILIAL'],
                'P_NRORG'      => $this->environment->getNrOrg()
            ];
            return empty($this->supUtilities->crud($query, $params));
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertPrazoFornExpedProd($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $ins = "INSERT INTO PRAZOFORNEXPEDFILPROD (NRPRAZOFORNEXPEDPROD, 
                                                       CDFORNECED, 
                                                       CDFILIAL, 
                                                       CDPRODUTO, 
                                                       QTDIASPRAZOEXPED,
                                                       VRMINFORNREG,
                                                       QTMINFORNREG)
                                                SELECT SEQ_PRAZOFORNEXPEDFILPROD.NEXTVAL,
                                                       FORNECEDOR.CDFORNECED,
                                                       FILIAL.CDFILIAL,
                                                       :P_CDPRODUTO,
                                                       :P_QTDIASPRAZOEXPED,
                                                       :P_VRMINFORNREG,
                                                       :P_QTMINFORNREG
                                                  FROM LISTA FO, LISTA FI, FORNECEDOR, FILIAL
                                                 WHERE FO.CDLISTA = FORNECEDOR.CDFORNECED
                                                   AND FI.CDLISTA = FILIAL.CDFILIAL
                                                   AND FO.NRLISTA = :P_CDFORNECED
                                                   AND FI.NRLISTA = :P_CDFILIAL
                                                   AND NOT EXISTS (SELECT 1
                                                                     FROM PRAZOFORNEXPEDFILPROD PZ
                                                                    WHERE PZ.CDFORNECED = FORNECEDOR.CDFORNECED
                                                                      AND PZ.CDFILIAL   = FILIAL.CDFILIAL
                                                                      AND PZ.CDPRODUTO  = :P_CDPRODUTO)
                                                  AND NOT EXISTS (SELECT 1
                                                                    FROM REFORFIL
                                                                   WHERE REFORFIL.CDPERIENTR IS NULL
                                                                     AND REFORFIL.CDFILIAL   = FILIAL.CDFILIAL
                                                                     AND REFORFIL.CDFORNECED = FORNECEDOR.CDFORNECED)";
        } else {
            $ins = "INSERT INTO PRAZOFORNEXPEDFILPROD (NRPRAZOFORNEXPEDPROD, 
                                                       CDFORNECED, 
                                                       CDFILIAL, 
                                                       CDPRODUTO, 
                                                       QTDIASPRAZOEXPED,
                                                       VRMINFORNREG,
                                                       QTMINFORNREG)
                                                SELECT SEQ_PRAZOFORNEXPEDFILPROD.NEXTVAL,
                                                       FORNECEDOR.CDFORNECED,
                                                       FILIAL.CDFILIAL,
                                                       :P_CDPRODUTO,
                                                       :P_QTDIASPRAZOEXPED,
                                                       :P_VRMINFORNREG,
                                                       :P_QTMINFORNREG
                                                  FROM FORNECEDOR, FILIAL
                                                 WHERE FORNECEDOR.CDFORNECED = :P_CDFORNECED
                                                   AND FILIAL.CDFILIAL       = :P_CDFILIAL
                                                   AND NOT EXISTS (SELECT 1
                                                                     FROM PRAZOFORNEXPEDFILPROD PZ
                                                                    WHERE PZ.CDFORNECED = FORNECEDOR.CDFORNECED
                                                                      AND PZ.CDFILIAL   = FILIAL.CDFILIAL
                                                                      AND PZ.CDPRODUTO  = :P_CDPRODUTO)";
        }                                                                      
        
        try {
            $params = [
                'P_CDFORNECED'       => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'P_CDFILIAL'         => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_CDPRODUTO'        => $row['CDPRODUTO'],
                'P_QTDIASPRAZOEXPED' => isset($row['QTDIASPRAZOEXPED']) ? $row['QTDIASPRAZOEXPED'] : null,
                'P_VRMINFORNREG'     => isset($row['VRMINFORNREG']) ? $row['VRMINFORNREG'] : null,
                'P_QTMINFORNREG'     => isset($row['QTMINFORNREG']) ? $row['QTMINFORNREG'] : null
            ];
            $this->supUtilities->crud($ins, $params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updatePrazoFornExpedProd($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $upt = "UPDATE PRAZOFORNEXPEDFILPROD
                       SET QTDIASPRAZOEXPED = :P_QTDIASPRAZOEXPED,
                           VRMINFORNREG     = :P_VRMINFORNREG,
                           QTMINFORNREG     = :P_QTMINFORNREG
                     WHERE EXISTS (SELECT 1
                                     FROM PRAZOFORNEXPEDFILPROD PZ
                                     JOIN LISTA FO ON PZ.CDFORNECED = FO.CDLISTA
                                     JOIN LISTA FI ON PZ.CDFILIAL   = FI.CDLISTA
                                    WHERE PZ.NRPRAZOFORNEXPEDPROD = PRAZOFORNEXPEDFILPROD.NRPRAZOFORNEXPEDPROD
                                      AND FO.NRLISTA   = :P_CDFORNECED
                                      AND FI.NRLISTA   = :P_CDFILIAL
                                      AND PZ.CDPRODUTO = :P_CDPRODUTO)";
            
        } else {
            $upt = "UPDATE PRAZOFORNEXPEDFILPROD
                       SET QTDIASPRAZOEXPED = :P_QTDIASPRAZOEXPED,
                           VRMINFORNREG     = :P_VRMINFORNREG,
                           QTMINFORNREG     = :P_QTMINFORNREG
                     WHERE CDFORNECED = :P_CDFORNECED
                       AND CDFILIAL   = :P_CDFILIAL
                       AND CDPRODUTO  = :P_CDPRODUTO";
        }
        
        try {
            $params = [
                'P_CDFORNECED'       => isset($nrlistaForn) ? $nrlistaForn : $row['CDFORNECED'],
                'P_CDFILIAL'         => isset($nrlistaFili) ? $nrlistaFili : $row['CDFILIAL'],
                'P_CDPRODUTO'        => $row['CDPRODUTO'],
                'P_QTDIASPRAZOEXPED' => isset($row['QTDIASPRAZOEXPED']) ? $row['QTDIASPRAZOEXPED'] : null,
                'P_VRMINFORNREG'     => isset($row['VRMINFORNREG']) ? $row['VRMINFORNREG'] : null,
                'P_QTMINFORNREG'     => isset($row['QTMINFORNREG']) ? $row['QTMINFORNREG'] : null
            ];
            $this->supUtilities->crud($upt, $params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function deletePrazoFornExpedProd($row, $nrlistaForn = null, $nrlistaFili = null)
    {
        $param = array();
        
        if(isset($nrlistaForn) && isset($nrlistaFili)){
            $sql = "DELETE FROM PRAZOFORNEXPEDFILPROD
                          WHERE EXISTS (SELECT 1
                                          FROM LISTA
                                         WHERE LISTA.NRLISTA = :P_CDFILIAL
                                           AND LISTA.CDLISTA = PRAZOFORNEXPEDFILPROD.CDFILIAL)
                            AND EXISTS (SELECT 1
                                          FROM LISTA
                                         WHERE LISTA.NRLISTA = :P_CDFORNECED
                                           AND LISTA.CDLISTA = PRAZOFORNEXPEDFILPROD.CDFORNECED)";
            $params = [
                'P_CDFORNECED' => $nrlistaForn,
                'P_CDFILIAL'   => $nrlistaFili
            ];
                                           
        } else {  
        
            if(isset($row['NRPRAZOFORNEXPEDPROD'])) {
                $sql = "DELETE FROM PRAZOFORNEXPEDFILPROD
                              WHERE NRPRAZOFORNEXPEDPROD = :P_NRPRAZOFORNEXPEDPROD";
                              
                $params = [
                    'P_NRPRAZOFORNEXPEDPROD' => $row['NRPRAZOFORNEXPEDPROD']
                ];
            } else {
                $sql = "DELETE FROM PRAZOFORNEXPEDFILPROD
                              WHERE CDFORNECED = :P_CDFORNECED
                                AND CDFILIAL   = :P_CDFILIAL";
                
                $params = [
                    'P_CDFORNECED' => $row['CDFORNECED'],
                    'P_CDFILIAL'   => $row['CDFILIAL']
                ];
            }
        }
        
        try {
            $this->supUtilities->crud($sql, $params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function saveFornecedor($row)
    {
        try {
            $query ="UPDATE FORNECEDOR
                        SET VRMINAUTFOR = :VRMINAUTFOR, 
                            QTMINAUTFOT = :QTMINAUTFOT 
                      WHERE CDFORNECED  = :P_CDFORNECED";
            $params = [
                "VRMINAUTFOR"  => isset($row['VRMINAUTFOR']) ? $row['VRMINAUTFOR'] : 0,
                "QTMINAUTFOT"  => isset($row['QTMINAUTFOT']) ? $row['QTMINAUTFOT'] : 0,
                "P_CDFORNECED" => $row['CDFORNECED']
            ];                      
            $this->supUtilities->crud($query, $params);
        } catch (Exception $e) {
            throw $e;
        }
          
    }
    
    /***************************************************************************/
    
    private function concatArray($array)
    {
        return is_array($array) && count($array) > 0 ? join('_', $array) : 'T';
    }
    
    private function insertLista($nrlista, $cdlista)
    {
        $query = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) 
                             VALUES (:NRLISTA, :CDLISTA, :NRORG)";
        
        $params = [
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista,
            "NRORG"   => $this->environment->getNrOrg()
        ];                      
            
        try {
            $this->supUtilities->crud($query, $params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function exportReforfil($row)
    {
        $nrlista = $this->supUtilities->generateCode('LISTA');
        
        try {
            if($this->concatArray($row['CDFILDEST']) == 'T') {
                $this->insertLista($nrlista, 'T');    
            } else {
                foreach($row['CDFILDEST'] as $cdfildest) {
                    $this->insertLista($nrlista, $cdfildest);
                }
            }
            
            $this->procExportFornecedor($nrlista, $row['CDFILIALORIG']);
            $this->deleteLista($nrlista);
        
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    private function deleteLista($nrlista)
    {
        $query = "DELETE FROM LISTA
                   WHERE NRLISTA = :P_NRLISTA";
                   
        $params = [
            "P_NRLISTA" => $nrlista
        ];   
        
        try {
            $this->supUtilities->crud($query, $params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    private function procExportFornecedor($P_NRLISTA, $P_CDFILORIG)
    {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'EXPORTA_REFORFIL');
        $procedure->addParam(new Param('P_NRLISTA', Param::PARAM_INPUT, $P_NRLISTA, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILORIG', Param::PARAM_INPUT, $P_CDFILORIG, Param::PARAM_TYPE_STR));
        $rowsaffect = $procedure->execute();
    }
}